package com.cirs.biz.service;

import java.util.HashMap;
import java.util.List;
import com.cirs.biz.domain.TEvaluation;
import com.cirs.biz.domain.avgEvaluation;

/**
 * 评价Service接口
 * 
 * @author allen
 * @date 2023-11-03
 */
public interface ITEvaluationService 
{
    /**
     * 查询评价
     * 
     * @param id 评价主键
     * @return 评价
     */
    public TEvaluation selectTEvaluationById(Long id);

    /**
     * 查询评价列表
     * 
     * @param tEvaluation 评价
     * @return 评价集合
     */
    public List<TEvaluation> selectTEvaluationList(TEvaluation tEvaluation);

    /**
     * 新增评价
     * 
     * @param tEvaluation 评价
     * @return 结果
     */
    public int insertTEvaluation(TEvaluation tEvaluation);

    /**
     * 修改评价
     * 
     * @param tEvaluation 评价
     * @return 结果
     */
    public int updateTEvaluation(TEvaluation tEvaluation);

    /**
     * 批量删除评价
     * 
     * @param ids 需要删除的评价主键集合
     * @return 结果
     */
    public int deleteTEvaluationByIds(Long[] ids);

    /**
     * 删除评价信息
     * 
     * @param id 评价主键
     * @return 结果
     */
    public int deleteTEvaluationById(Long id);

    public Float getscore(String componentid);

    public List<avgEvaluation> get_top10();
}
